@@ -78,6 +78,7 @@ def extract_image_ml_predictions(
         # detection.
         nutriscore_prediction = extract_nutriscore_label(
             image,
+            source_image,
             manual_threshold=0.5,
         )
 
@@ -118,6 +119,7 @@ NUTRISCORE_LABELS: Dict[str, str] = {
 
 def extract_nutriscore_label(
     image: Image.Image,
+    source_image: str,
     manual_threshold: float,
     automatic_threshold: Optional[float] = None,
 ) -> Optional[Prediction]:
@@ -142,6 +144,7 @@ def extract_nutriscore_label(
 
     return Prediction(
         type=PredictionType.label,
+        source_image=source_image,
         value_tag=label_tag,
         automatic_processing=automatic_processing,
         data={
