@@ -41,7 +41,7 @@ def run_import_image_job(
     product = get_product_store()[barcode]
     if product is None:
         logger.warning(
-            f"Product {barcode} does not exist during image import ({source_image})"
+            "Product %s does not exist during image import (%s)", barcode, source_image
         )
         return
 
@@ -183,7 +183,8 @@ def run_object_detection(
         except requests.exceptions.HTTPError as e:
             resp = e.response
             logger.warning(
-                f"Could not save nearest neighbors in ANN: {resp.status_code}: {resp.text}"
+                f"Could not save nearest neighbors in ANN: {resp.status_code}: %s",
+                resp.text,
             )
 
         thresholds = LOGO_CONFIDENCE_THRESHOLDS.get()
